@@ -41,6 +41,18 @@ class TestCase(base.FunctionalTestBase):
     def construct_cmd(*parts):
         return ' '.join(str(x) for x in parts)
 
+    @staticmethod
+    def generate_params(argument, params):
+        """Generate parameters string.
+
+        :param argument: argument
+        :param params: values passed with argument
+        """
+        parts = []
+        for key, value in params.items():
+            parts.append('{} {}={}'.format(argument, key, value))
+        return ' '.join(parts)
+
     def assert_dict_is_subset(self, expected, actual):
         """Check if expected keys/values exist in actual response body.
 
@@ -324,6 +336,19 @@ class TestCase(base.FunctionalTestBase):
                                 .format(opts, params))
         return json.loads(output)
 
+    def driver_raid_property_list(self, driver_name, fields=None, params=''):
+        """List a driver's RAID logical disk properties.
+
+        :param String driver_name: Name of the driver
+        :param List fields: List of fields to show
+        :param List params: Additional kwargs
+        :return: list of JSON driver RAID properties objects
+        """
+        opts = self.get_opts(fields=fields)
+        output = self.openstack('baremetal driver raid property list {} {} {}'
+                                .format(opts, driver_name, params))
+        return json.loads(output)
+
     def conductor_show(self, hostname, fields=None, params=''):
         """Show specified baremetal conductors.
 
