@@ -52,6 +52,7 @@ class Resource(object):
         'default_boot_interface': 'Default Boot Interface',
         'default_console_interface': 'Default Console Interface',
         'default_deploy_interface': 'Default Deploy Interface',
+        'default_firmware_interface': 'Default Firmware Interface',
         'default_inspect_interface': 'Default Inspect Interface',
         'default_management_interface': 'Default Management Interface',
         'default_network_interface': 'Default Network Interface',
@@ -70,6 +71,7 @@ class Resource(object):
         'enabled_boot_interfaces': 'Enabled Boot Interfaces',
         'enabled_console_interfaces': 'Enabled Console Interfaces',
         'enabled_deploy_interfaces': 'Enabled Deploy Interfaces',
+        'enabled_firmware_interfaces': 'Enabled Firmware Interfaces',
         'enabled_inspect_interfaces': 'Enabled Inspect Interfaces',
         'enabled_management_interfaces': 'Enabled Management Interfaces',
         'enabled_network_interfaces': 'Enabled Network Interfaces',
@@ -152,6 +154,11 @@ class Resource(object):
         'id': 'ID',
         'connector_id': 'Connector ID',
         'is_smartnic': 'Is Smart NIC port',
+        'parent_node': 'Parent Node',
+        'children': 'Child Nodes',
+        'firmware_interface': 'Firmware Interface',
+        'port_name': 'Port Name',
+        'public': 'Public'
     }
 
     def __init__(self, field_ids, sort_excluded=None, override_labels=None):
@@ -254,6 +261,7 @@ NODE_DETAILED_RESOURCE = Resource(
      'driver_internal_info',
      'extra',
      'fault',
+     'firmware_interface',
      'inspect_interface',
      'inspection_finished_at',
      'inspection_started_at',
@@ -268,6 +276,7 @@ NODE_DETAILED_RESOURCE = Resource(
      'network_data',
      'network_interface',
      'owner',
+     'parent_node',
      'power_interface',
      'power_state',
      'properties',
@@ -338,6 +347,7 @@ PORT_DETAILED_RESOURCE = Resource(
      'updated_at',
      'internal_info',
      'is_smartnic',
+     'port_name',
      ],
     sort_excluded=[
         'extra',
@@ -392,6 +402,10 @@ TRAIT_RESOURCE = Resource(
     ['traits'],
 )
 
+CHILDREN_RESOURCE = Resource(
+    ['children'],
+)
+
 BIOS_RESOURCE = Resource(
     ['name', 'value'],
     override_labels={'name': 'BIOS setting name',
@@ -422,6 +436,7 @@ DRIVER_DETAILED_RESOURCE = Resource(
      'default_boot_interface',
      'default_console_interface',
      'default_deploy_interface',
+     'default_firmware_interface',
      'default_inspect_interface',
      'default_management_interface',
      'default_network_interface',
@@ -434,6 +449,7 @@ DRIVER_DETAILED_RESOURCE = Resource(
      'enabled_boot_interfaces',
      'enabled_console_interfaces',
      'enabled_deploy_interfaces',
+     'enabled_firmware_interfaces',
      'enabled_inspect_interfaces',
      'enabled_management_interfaces',
      'enabled_network_interfaces',
@@ -452,6 +468,22 @@ DRIVER_RESOURCE = Resource(
     override_labels={'name': 'Supported driver(s)'}
 )
 
+# Firmware
+FIRMWARE_RESOURCE = Resource(
+    ['component',
+     'initial_version',
+     'current_version',
+     'last_version_flashed',
+     'created_at',
+     'updated_at',
+     ],
+    override_labels={'component': 'Component',
+                     'initial_version': 'Initial Version',
+                     'current_version': 'Current Version',
+                     'last_version_flashed': 'Last Version Flashed'}
+)
+
+
 # Volume connectors
 VOLUME_CONNECTOR_DETAILED_RESOURCE = Resource(
     ['uuid',
@@ -575,6 +607,25 @@ DEPLOY_TEMPLATE_RESOURCE = Resource(
      ],
 )
 
+# Runbooks
+RUNBOOK_DETAILED_RESOURCE = Resource(
+    ['uuid',
+     'name',
+     'owner',
+     'public',
+     'steps',
+     'extra',
+     'created_at',
+     'updated_at'
+     ],
+    sort_excluded=['extra', 'steps']
+)
+
+RUNBOOK_RESOURCE = Resource(
+    ['uuid',
+     'name',
+     ],
+)
 
 NODE_HISTORY_RESOURCE = Resource(
     ['uuid',
